@@ -180,7 +180,11 @@ def _pool_normxcorr(templates, stream, pool, func, *args, **kwargs):
               for sid in seed_ids)
     # get cc results and used chans into their own lists
     results = [pool.apply_async(func, param) for param in params]
-    xcorrs, tr_chans = zip(*(res.get() for res in results))
+    try:
+        xcorrs, tr_chans = zip(*(res.get() for res in results))
+    except KeyboardInterrupt as e:  # pragma: no cover
+        pool.terminate()
+        raise e
     cccsums = np.sum(xcorrs, axis=0)
     no_chans = np.sum(np.array(tr_chans).astype(np.int), axis=0)
     for seed_id, tr_chan in zip(seed_ids, tr_chans):
@@ -533,6 +537,12 @@ def fftw_normxcorr(templates, stream, pads, threaded=False, *args, **kwargs):
     pads_np = np.ascontiguousarray(pads, dtype=np.intc)
     variance_warning = np.ascontiguousarray([0], dtype=np.intc)
 
+    # Check that stream is non-zero and above variance threshold
+    if not np.all(stream == 0) and np.var(stream) < 1e-8:
+        # Apply gain
+        stream *= 1e8
+        warnings.warn("Low variance found for, applying gain "
+                      "to stabilise correlations")
     ret = func(
         np.ascontiguousarray(norm.flatten(order='C'), np.float32),
         template_length, n_templates,
@@ -732,6 +742,13 @@ def fftw_multi_normxcorr(template_array, stream_array, pad_array, seed_ids,
     template_array = np.ascontiguousarray([template_array[x]
                                            for x in seed_ids],
                                           dtype=np.float32)
+    for x in seed_ids:
+        # Check that stream is non-zero and above variance threshold
+        if not np.all(stream_array[x] == 0) and np.var(stream_array[x]) < 1e-8:
+            # Apply gain
+            stream_array *= 1e8
+            warnings.warn("Low variance found for {0}, applying gain "
+                          "to stabilise correlations".format(x))
     stream_array = np.ascontiguousarray([stream_array[x] for x in seed_ids],
                                         dtype=np.float32)
     cccs = np.zeros((n_templates, image_len - template_len + 1),
